@@ -1,4 +1,4 @@
-from PyHydro import fcf
+from PyHydro.fcf import fcf
 from itertools import product
 from cvxopt.modeling import op, variable, matrix
 import cvxopt.solvers as solvers
@@ -7,8 +7,8 @@ import cvxopt.solvers as solvers
 from matplotlib import pyplot as plt
 import numpy as np
 from multiprocessing import Pool
-from PyHydro import pmo
-from PyHydro import dadosgerais
+from PyHydro.pmo import pmo
+from PyHydro.dadosgerais import dadosgerais
 from functools import partial
 from timeit import default_timer as timer
 
