@@ -1,4 +1,4 @@
-from PyHydro import mddh
+from PyHydro.mddh import mddh
 import os
 
 sistema = mddh(os.path.join(os.getcwd(), 'pmo/'))
