@@ -1,9 +1,9 @@
 import struct
-from PyHydro import hidr
-from PyHydro import term
-from PyHydro import resequiv
-from PyHydro import submercado as subsist
-from PyHydro import interc
+from PyHydro.hidr import hidr
+from PyHydro.term import term
+from PyHydro.resequiv import resequiv
+from PyHydro.submercado import submercado as subsist
+from PyHydro.interc import interc
 import numpy as np
 
 class pmo(object):
